<?php # $Id: serendipity_lang_cs.inc.php 2083 2008-01-03 15:02:22Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation (c) 2004 Josef Klimosz <ok2wo@centrum.cz>
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'UTF-8');
@define('SQL_CHARSET', 'utf8');
@define('DATE_LOCALES', 'cs_CZ.UTF-8, czech, cs');
@define('DATE_FORMAT_ENTRY', '%A, %e. %B %Y');
@define('DATE_FORMAT_SHORT', '%d/%m/%Y %H.%M');
@define('WYSIWYG_LANG', 'cs-utf');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', ',');
@define('NUMBER_FORMAT_THOUSANDS', ' ');
@define('LANG_DIRECTION', 'ltr');

$i18n_filename_from = array (
'á','č','ď','é','ě','í','ĺ','ľ','ň','ó','ŕ','ř','ś','š','ť','ú','ů','ý','ź','ž',
'Á','Č','Ď','É','Ě','Í','Ĺ','Ľ','Ň','Ó','Ŕ','Ř','Ś','Š','Ť','Ú','Ů','Ý','Ź','Ž',
' ',',','.','!',
);
$i18n_filename_to = array (
'a','c','d','e','e','i','l','l','n','o','r','r','s','s','t','u','u','y','z','z',
'A','C','D','E','E','I','L','L','N','O','R','R','S','S','T','U','U','Y','Z','Z',
'-', '', '', '',
);

@define('SERENDIPITY_ADMIN_SUITE', 'Administrátorská sekce');
@define('HAVE_TO_BE_LOGGED_ON', 'Pro zobrazení této stránky musíte být přihlášen');
@define('WRONG_USERNAME_OR_PASSWORD', 'Zřejmě jste vložil špatné jméno nebo heslo!');
@define('APPEARANCE', 'Vzhled');
@define('MANAGE_STYLES', 'Změna stylu');
@define('CONFIGURE_PLUGINS', 'Konfigurace pluginů');
@define('CONFIGURATION', 'Konfigurace');
@define('BACK_TO_BLOG', 'Zpět do weblogu');
@define('LOGIN', 'Přihlášení');
@define('LOGOUT', 'Odhlášení');
@define('LOGGEDOUT', 'Odhlášen');
@define('CREATE', 'Vytvořit');
@define('SAVE', 'Uložit');
@define('NAME', 'Jméno');
@define('CREATE_NEW_CAT', 'Vytvoření nové kategorie');
@define('I_WANT_THUMB', 'Použít náhled.');
@define('I_WANT_BIG_IMAGE', 'Použít celý obrázek.');
@define('I_WANT_NO_LINK', ' Zobrazit jako obrázek');
@define('I_WANT_IT_TO_LINK', 'Zobrazit jako odkaz (URL):');
@define('BACK', 'Zpět');
@define('FORWARD', 'Dále');
@define('ANONYMOUS', 'Anonym');
@define('NEW_TRACKBACK_TO', 'Nová odezva na');
@define('NEW_COMMENT_TO', 'Nový komentář k');
@define('RECENT', 'Nové...');
@define('OLDER', 'Starší...');
@define('DONE', 'Hotovo');
@define('WELCOME_BACK', 'Vítejte zpět,');
@define('TITLE', 'Titulek');
@define('DESCRIPTION', 'Popis');
@define('PLACEMENT', 'Umístění');
@define('DELETE', 'Vymazat');
@define('SAVE', 'Uložit');
@define('UP', 'Nahoru');
@define('DOWN', 'Dolů');
@define('ENTRIES', 'záznamy');
@define('NEW_ENTRY', 'Nový záznam');
@define('EDIT_ENTRIES', 'Editovat záznamy');
@define('CATEGORIES', 'Kategorie');
@define('WARNING_THIS_BLAHBLAH', "POZOR:\\nTato akce může trvat déle, pokud máte mnoho obrázků bez náhledů.");
@define('CREATE_THUMBS', 'Vytvořit náhledy');
@define('MANAGE_IMAGES', 'Správa obrázků');
@define('NAME', 'Jméno');
@define('EMAIL', 'E-mail');
@define('HOMEPAGE', 'Domácí stránka');
@define('COMMENT', 'Komentář');
@define('REMEMBER_INFO', 'Zapamatovat informace? ');
@define('SUBMIT_COMMENT', 'Odeslat komentář');
@define('NO_ENTRIES_TO_PRINT', 'Žádné záznamy k zobrazení');
@define('COMMENTS', 'Komentáře');
@define('ADD_COMMENT', 'Přidat komentář');
@define('NO_COMMENTS', 'Žádné komentáře');
@define('POSTED_BY', 'Vložil');
@define('ON', 'v');
@define('A_NEW_COMMENT_BLAHBLAH', 'Nový komentář k weblogu "%s", k záznamu s názvem "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'Nová odezva na weblog/záznam s názvem "%s".');
@define('NO_CATEGORY', 'Žádná kategorie');
@define('ENTRY_BODY', 'Text záznamu');
@define('EXTENDED_BODY', 'Rozšířená textová část');
@define('CATEGORY', 'Kategorie');
@define('EDIT', 'Editace');
@define('NO_ENTRIES_BLAHBLAH', 'Nenalezen žádný záznam odpovídající volbě %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Vyhledávání %s odpovídá %s výsledků:');
@define('IMAGE', 'Obrázek');
@define('ERROR_FILE_NOT_EXISTS', 'Chyba: Jméno souboru neexistuje!');
@define('ERROR_FILE_EXISTS', 'Chyba: Toto jméno souboru je už použito, zvolte jiné!');
@define('ERROR_SOMETHING', 'Chyba: Něco je špatně.');
@define('ADDING_IMAGE', 'Přidání obrázku...');
@define('THUMB_CREATED_DONE', 'Náhled je vytvořen.<br>Hotovo.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Chyba: Soubor už ve vašem počítači existuje!');
@define('GO', 'Provést!');
@define('NEWSIZE', 'Nový rozměr: ');
@define('RESIZE_BLAHBLAH', '<b>Změnit rozměr %s</b><p>');
@define('ORIGINAL_SIZE', 'Původní rozměr: <i>%sx%s</i> pixelů');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Zde můžete zadat nový rozměr obrázku. Pokud chcete zachovat proporce, zadejte jen jednu hodnotu a stiskněte klávesu TAB, nový rozměr bude dopočítán automaticky:');
@define('QUICKJUMP_CALENDAR', 'Vyhledávací kalendář');
@define('QUICKSEARCH', 'Rychlé hledání');
@define('SEARCH_FOR_ENTRY', 'Hledání záznamu');
@define('ARCHIVES', 'Archivy');
@define('BROWSE_ARCHIVES', 'Prohlížení měsíčních archivů');
@define('TOP_REFERRER', 'Top odkazovače');
@define('SHOWS_TOP_SITES', 'Nejčastější připojení k tomuto weblogu');
@define('TOP_EXITS', 'Top výstupy');
@define('SHOWS_TOP_EXIT', 'Nejčastější výstupy z tohoto weblogu');
@define('SYNDICATION', 'Spolupráce');
@define('SHOWS_RSS_BLAHBLAH', 'Sdílené RSS linky');
@define('ADVERTISES_BLAHBLAH', 'Reklama na tvůrce systému vašeho weblogu');
@define('HTML_NUGGET', 'Vložený HTML kód');
@define('HOLDS_A_BLAHBLAH', 'Vložení HTML kódu do postranního sloupce');
@define('TITLE_FOR_NUGGET', 'Název HTML kódu');
@define('THE_NUGGET', 'Vložený HTML');
@define('SYNDICATE_THIS_BLOG', 'Sdílení weblogu');
@define('YOU_CHOSE', 'Vybral jste %s');
@define('IMAGE_SIZE', 'Obrázek o rozměru');
@define('IMAGE_AS_A_LINK', 'Vložení obrázku');
@define('POWERED_BY', 'Vytvořeno pomocí');
@define('SUPERUSER', 'Superuživatel');
@define('TRACKBACKS', 'Odezvy');
@define('TRACKBACK', 'Odezva');
@define('NO_TRACKBACKS', 'Žádné odezvy');
@define('TOPICS_OF', 'Téma');
@define('VIEW_FULL', 'Zobrazit vše');
@define('VIEW_TOPICS', 'Zobrazit téma');
@define('AT', 'v');
@define('SET_AS_TEMPLATE', 'Nastavit jako vzor');
@define('IN', 've');
@define('EXCERPT', 'Výpis');
@define('TRACKED', 'Sledován');
@define('LINK_TO_ENTRY', 'Odkaz na záznam');
@define('LINK_TO_REMOTE_ENTRY', 'Odkaz na externí záznam');
@define('IP_ADDRESS', 'IP adresa');
@define('USER', 'Uživatel');
@define('THUMBNAIL_USING_OWN', '%s je použit jako vlastní náhled, protože je příliš malý.');
@define('THUMBNAIL_FAILED_COPY', '%s nelze použít jako vlastní náhled, neboť jej nelze zkopírovat!');
@define('AUTHOR', 'Autor');
@define('LAST_UPDATED', 'Naposled změněno');
@define('TRACKBACK_SPECIFIC', 'Odezva ze specifického URI na tento záznam');
@define('DIRECT_LINK', 'Přímý odkaz na tento záznam');
@define('COMMENT_ADDED', 'Váš komentář byl úspěšně přidán.');
@define('COMMENT_ADDED_CLICK', 'Klikněte %ssem%s pro návrat ke komentářům nebo %ssem%s pro zavření okna.');
@define('COMMENT_NOT_ADDED_CLICK', 'Klikněte %ssem%s pro návrat ke komentářům nebo %ssem%s pro zavření okna.');
@define('COMMENTS_DISABLE', 'Neumožnit přidávání komentářů');
@define('COMMENTS_ENABLE', 'Umožnit přidávání komentářů');
@define('COMMENTS_CLOSED', 'Autor neumožnil přidávat komentáře');
@define('EMPTY_COMMENT', 'Váš komentář nic neobsahuje, %svraťte se%s a zkuste to znovu');
@define('ENTRIES_FOR', 'Záznamy: %s');
@define('DOCUMENT_NOT_FOUND', 'Dokument %s nebyl nalezen.');
@define('USERNAME', 'Jméno (přezdívka)');
@define('PASSWORD', 'Heslo');
@define('AUTOMATIC_LOGIN', 'Uložit informace');
@define('SERENDIPITY_INSTALLATION', 'Instalace Serendipity');
@define('LEFT', 'vlevo');
@define('RIGHT', 'vpravo');
@define('HIDDEN', 'skrytý');
@define('REMOVE_TICKED_PLUGINS', 'Odstranit označené pluginy');
@define('SAVE_CHANGES_TO_LAYOUT', 'Uložit změny layoutu');
@define('COMMENTS_FROM', 'Komentáře od');
@define('ERROR', 'Chyba');
@define('ENTRY_SAVED', 'Záznam uložen');
@define('DELETE_SURE', 'Určitě chcete vymazat #%s natrvalo?');
@define('NOT_REALLY', 'Nechci...');
@define('DUMP_IT', 'Vymazat!');
@define('RIP_ENTRY', 'Zrušen záznam #%s');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Kategorie #%s byla zrušena. Starší záznamy byly přemístěny do #%s');
@define('CATEGORY_DELETED', 'Kategorie #%s byla zrušena.');
@define('INVALID_CATEGORY', 'Žádná kategorie nebyla určena k vymazání');
@define('CATEGORY_SAVED', 'Kategorie uložena');
@define('SELECT_TEMPLATE', 'Vyberte vzor pro váš web');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Záznamy nebyly vloženy úspěšně!');
@define('YES', 'Ano');
@define('NO', 'Ne');
@define('USE_DEFAULT', 'Default');
@define('CHECK_N_SAVE', 'Prověřit a uložit');
@define('DIRECTORY_WRITE_ERROR', 'Nelze zapisovat do adresáře %s - prověřte oprávnění.');
@define('DIRECTORY_CREATE_ERROR', 'Adresář %s neexistuje a nemohl být vytvořen. Vytvořte adresář manuálně.');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; spustit <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Nelze spustit binární soubor %s.');
@define('FILE_WRITE_ERROR', 'Nelze zapisovat do souboru %s.');
@define('FILE_CREATE_YOURSELF', 'Vytvořte soubor přímo nebo prověřte oprávnění');
@define('COPY_CODE_BELOW', '<br />* Zkopírujte kód uvedený níže a umístěte jej do %s ve vašem %s adresáři:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Změňte www na uživatele, který je určen v Apache (na př. nobody).');
@define('BROWSER_RELOAD', 'Po dokončení stiskněte tlačítko obnovení stránky ve vašem prohlížeči.');
@define('DIAGNOSTIC_ERROR', 'Diagnostika detekovala nějaké chyby ve vkládaných informacích:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity ještě není nainstalován. <a href="%s">Instalujte</a> jej nyní.');
@define('INCLUDE_ERROR', 'chyba serendipity: nelze vložit %s - ukončeno.');
@define('DATABASE_ERROR', 'chyba serendipity: nelze se spojit s databází - ukončeno.');
@define('CREATE_DATABASE', 'Vytvoření základní databáze...');
@define('ATTEMPT_WRITE_FILE', 'Pokus uložit soubor %s...');
@define('WRITTEN_N_SAVED', 'Konfigurace byla zapsána a uložena');
@define('IMAGE_ALIGNMENT', 'Úprava obrázku');
@define('ENTER_NEW_NAME', 'Nový název: ');
@define('RESIZING', 'Změna rozměrů');
@define('RESIZE_DONE', 'Hotovo (upraven rozměr %s obrázků).');
@define('SYNCING', 'Synchronizace databáze s adresářem obrázků');
@define('SYNC_DONE', 'Hotovo (synchronizováno %s obrázků).');
@define('DELETE_IMAGE_FAIL' , 'Nelze vymazat obrázek <b>%s</b>');
@define('DELETE_THUMBNAIL', 'Vymazán náhled obrázku s názvem <b>%s</b>');
@define('FILE_NOT_FOUND', 'Nelze nalézt soubor s názvem <b>%s</b>, možná je opravdu vymazán?');
@define('ABORT_NOW', 'Zrušit');
@define('REMOTE_FILE_NOT_FOUND', 'Soubor nebyl na vzdáleném serveru nalezen, jste si jist že URL: <b>%s</b> je správné?');
@define('FILE_FETCHED', '%s nalezen');
@define('FILE_UPLOADED', 'Soubor %s je úspěšně nahrán.');
@define('WORD_OR', 'nebo');
@define('SCALING_IMAGE', 'Změna %s na %s x %s px');
@define('KEEP_PROPORTIONS', 'Zachovat proporce');
@define('REALLY_SCALE_IMAGE', 'Opravdu změnit rozměr? Nelze vrátit!');
@define('TOGGLE_ALL', 'Otevřít vše');
@define('TOGGLE_OPTION', 'Otevřít volbu');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Přihlásit se ke sledování komentářů k záznamu');
@define('UNSUBSCRIBE_OK', "%s je odhlášen ze sledování komentářů");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Nový komentář k přihlášenému záznamu "%s"');
@define('SUBSCRIPTION_MAIL', "Pozor %s,\n\nA právě byl přidán nový komentář k záznamu, který sledujete na \"%s\", s názvem \"%s\"\nJméno odesílatele: %s\n\nZáznam najdete zde: %s\n\nMůžete se odhlásit zde: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Pozor %s,\n\nA právě byla přidána nová odezva k záznamu, který sledujete na \"%s\", s názvem \"%s\"\nJméno odesílatele: %s\n\nZáznam najdete zde: %s\n\nMůžete se odhlásit zde: %s\n");
@define('SIGNATURE', "\n-- \n%s je vytvořen pomocí Serendipity.\n Tento perfektní blogovací systém můžete zdarma používat také.\nNavštivte <http://s9y.org>, kde se dozvíte vše potřebné.");
@define('SYNDICATION_PLUGIN_091', 'Kanál RSS 0.91');
@define('SYNDICATION_PLUGIN_20', 'Kanál RSS 2.0');
@define('SYNDICATION_PLUGIN_10', 'Kanál RSS 1.0');
@define('SYNDICATION_PLUGIN_20c', 'Komentáře RSS 2.0');
@define('SYNDICATION_PLUGIN_ATOM03', 'Kanál ATOM 0.3');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', 'Kanál %s');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Pole "hlavní redaktor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Pole "webmaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Obrázek kanálu RSS');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Šířka');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Výška');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'E-mailová adresa webmastera, je-li k dispozici. (prázdné: skryté) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'E-mailová adresa hlavního redaktora, je-li k dispozici. (prázdné: skryté) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL obrázku ve formátu GIF/JPEG/PNG, je-li k dispozici. (prázdné: logo serendipity)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'v pixelech, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'v pixelech, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Pole "ttl" (životnost)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Čas v minutách, po kterém by váš weblog neměl být nadále kešován v cizích serverech/aplikacích (prázdné: skryté) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Pole "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Pole "pubDate" je pro kanál RSS ukryto, chcete ukázat datum posledního záznamu?');
@define('CONTENT', 'Obsah');
@define('TYPE', 'Typ');
@define('DRAFT', 'Koncept');
@define('PUBLISH', 'Publikovat');
@define('PREVIEW', 'Ukázat');
@define('DATE', 'Datum');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Upozornění: Datum je specifikováno špatně. Použijte formát YYYY-MM-DD HH:MM.');
@define('CATEGORY_PLUGIN_DESC', 'Seznam kategorií.');
@define('ALL_AUTHORS', 'Všichni autoři');
@define('CATEGORIES_TO_FETCH', 'Vyhledat kategorie');
@define('CATEGORIES_TO_FETCH_DESC', 'Vyhledat kategorie podle autorů?');
@define('PAGE_BROWSE_ENTRIES', 'Stránka %s z %s, celkem %s záznamů');
@define('PREVIOUS_PAGE', 'předchozí stránka');
@define('NEXT_PAGE', 'další stránka');
@define('ALL_CATEGORIES', 'Všechny kategorie');
@define('DO_MARKUP', 'Umožnit převod značek');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Formátování data');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Formát aktuálního data záznamu, používá PHP proměnnou strftime(). (Přednastaveno: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Nelze otevřít vzorový soubor, updatujte Serendipity!');
@define('ADVANCED_OPTIONS', 'Rozšířené volby');
@define('EDIT_ENTRY', 'Editovat záznam');
@define('HTACCESS_ERROR', 'Prověřte instalaci vašeho webserveru, Serendipity potřebuje uložit soubor ".htaccess". To nebylo možné kvůli chybě oprávnění. Nastavte oprávnění jako: <br />&nbsp;&nbsp;%s<br />a znovu uložte tuto stránku.');
@define('SIDEBAR_PLUGINS', 'Pluginy pro postranní sloupce');
@define('EVENT_PLUGINS', 'Pluginy událostí');
@define('SORT_ORDER', 'Pořadí');
@define('SORT_ORDER_NAME', 'Název souboru');
@define('SORT_ORDER_EXTENSION', 'Rozšíření');
@define('SORT_ORDER_SIZE', 'Velikost');
@define('SORT_ORDER_WIDTH', 'Šířka obrázku');
@define('SORT_ORDER_HEIGHT', 'Výška obrázku');
@define('SORT_ORDER_DATE', 'Datum nahrání');
@define('SORT_ORDER_ASC', 'Vzestupně');
@define('SORT_ORDER_DESC', 'Sestupně');
@define('THUMBNAIL_SHORT', 'Náhl.');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'Zapnout značkování %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Začátek týdne');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity detekoval, že vaše konfigurace je uložena ve verzi %s, ale serendipity je instalován jako verze %s, je potřeba upgrade! <a href="%s">Klikněte zde</a>');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Vítá vás manažer upgrade Serendipity.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Pomohu vám s upgrade vaší instalace Serendipity %s.');
@define('SERENDIPITY_UPGRADER_WHY', 'Tato zpráva je zobrazena proto, že vaše instalace je Serendipity %s, ale ještě nebyla updatována databáze pro tuto verzi');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Update databáze (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'Zde jsou .sql soubory, která musíte spustit před pokračováním práce se Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Úlohy specifické pro tuto verzi');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Žádné specifické úlohy');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Mohu pokračovat v těchto úlohách?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Ne, spustím je manuálně');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Ano, pokračujte');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Není třeba žádný upgrade');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Serendipity je upgradován');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'Vynechal jste stupeň upgrade Serendipity, ujistěte se, že databáze je správně nainstalována a plánované funkce jsou spuštěny');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Vaše instalace Serendipity je upgradována na %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Kliknutím %ssem%s se vrátíte do vašeho weblogu');
@define('MANAGE_USERS', 'Správa uživatelů');
@define('CREATE_NEW_USER', 'Vytvořit nového uživatele');
@define('CREATE_NOT_AUTHORIZED', 'Nemůžete editovat uživatele se stejnou úrovní jako je vaše');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'Nemůžete vytvořit uživatele s vyšší úrovní než je vaše');
@define('CREATED_USER', 'Nový uživatel %s byl vytvořen');
@define('MODIFIED_USER', 'Nastavení uživatele %s byla změněna');
@define('USER_LEVEL', 'Úroveň');
@define('DELETE_USER', 'Chcete vymazat uživatele #%d %s. Myslíte to vážně? Tato akce znemožní prohlížet jím vytvořené záznamy na hlavní stránce.');
@define('DELETED_USER', 'Uživatel #%d %s je vymazán.');
@define('LIMIT_TO_NUMBER', 'Kolik záznamů by mělo být zobrazeno?');
@define('ENTRIES_PER_PAGE', 'záznamů na stránku');
@define('DIRECTORIES_AVAILABLE', 'Po kliknutí na některý adresář v seznamu můžete vytvořit další podadresář.');
@define('ALL_DIRECTORIES', 'všechny adresáře');
@define('MANAGE_DIRECTORIES', 'Práce s adresáři');
@define('DIRECTORY_CREATED', 'Adresář <strong>%s</strong> byl vytvořen.');
@define('PARENT_DIRECTORY', 'Základní adresář');
@define('CONFIRM_DELETE_DIRECTORY', 'Jste si jist, že chcete odstranit všechen obsah adresáře %s?');
@define('ERROR_NO_DIRECTORY', 'Chyba: Adresář %s neexistuje');
@define('CHECKING_DIRECTORY', 'Kontrola souborů v adresáři %s');
@define('DELETING_FILE', 'Vymazání souboru %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Nelze odstranit neprázdný adresář. Zkuste zvolit "vynucené mazání", pokud potřebujete vymazat tyto soubory, a odešlete požadavek znovu. Existující soubory jsou:');
@define('DIRECTORY_DELETE_FAILED', 'Vymazání adresáře %s se nepodařilo. Zkontrolujte oprávnění nebo čtěte zprávu výše.');
@define('DIRECTORY_DELETE_SUCCESS', 'Adresář %s byl úspěšně vymazán.');
@define('SKIPPING_FILE_EXTENSION', 'Vynechán soubor: Chybějící přípona %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Vynechán soubor: %s nelze načíst.');
@define('FOUND_FILE', 'Založit nový/změnit soubor: %s.');
@define('PERMISSIONS', 'Oprávnění');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Databáze');
@define('INSTALL_CAT_DB_DESC', 'Sem vložte všech informace o databázi. Serendipity je potřebuje k funkci.');
@define('INSTALL_DBTYPE', 'Typ');
@define('INSTALL_DBTYPE_DESC', 'Typ databáze');
@define('INSTALL_DBHOST', 'Hostitel');
@define('INSTALL_DBHOST_DESC', 'Název hostitelského serveru');
@define('INSTALL_DBUSER', 'Uživatel');
@define('INSTALL_DBUSER_DESC', 'Uživatelské jméno');
@define('INSTALL_DBPASS', 'Heslo');
@define('INSTALL_DBPASS_DESC', 'Uživatelské heslo');
@define('INSTALL_DBNAME', 'Název');
@define('INSTALL_DBNAME_DESC', 'Název databáze');
@define('INSTALL_DBPREFIX', 'Prefix');
@define('INSTALL_DBPREFIX_DESC', 'Prefix pro záznamy v databázi, např. serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Cesty');
@define('INSTALL_CAT_PATHS_DESC', 'Cesty k různým adresářům a souborům. Nezapomeňte na ukončovací lomítko pro adresáře!');
@define('INSTALL_FULLPATH', 'Úplná cesta');
@define('INSTALL_FULLPATH_DESC', 'Úplná absolutní cesta k vaší instalaci Serendipity.');
@define('INSTALL_UPLOADPATH', 'Cesta pro uploady');
@define('INSTALL_UPLOADPATH_DESC', 'Sem budou směrovány uploady, relativně k \'úplné cestě\' - typicky \'uploads/\'');
@define('INSTALL_RELPATH', 'Relativní cesta');
@define('INSTALL_RELPATH_DESC', 'Cesta k Serendipity pro váš prohlížeč, typicky \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Relativní cesta k template');
@define('INSTALL_RELTEMPLPATH_DESC', 'Cesta k adresáři, obsahujícímu vzory (templates) - relativní k \'relativní cestě\'');
@define('INSTALL_RELUPLOADPATH', 'Relativní cesta k uploadům');
@define('INSTALL_RELUPLOADPATH_DESC', 'Cesta k uploadům pro prohlížeče - relativní k \'relativní cestě\'');
@define('INSTALL_URL', 'URL weblogu');
@define('INSTALL_URL_DESC', 'Základní URL vaší instalace Serendipity');
@define('INSTALL_INDEXFILE', 'Indexový soubor');
@define('INSTALL_INDEXFILE_DESC', 'Název souboru použitého jako index');

/* Generel settings */
@define('INSTALL_CAT_SETTINGS', 'Základní nastavení');
@define('INSTALL_CAT_SETTINGS_DESC', 'Úprava správy Serendipity');
@define('INSTALL_USERNAME', 'Jméno admina');
@define('INSTALL_USERNAME_DESC', 'Jméno pro přihlášení admina');
@define('INSTALL_PASSWORD', 'Heslo admina');
@define('INSTALL_PASSWORD_DESC', 'Heslo pro přihlášení admina');
@define('INSTALL_EMAIL', 'E-mail admina');
@define('INSTALL_EMAIL_DESC', 'E-mail pro přihlášení admina');
@define('INSTALL_SENDMAIL', 'Posílat e-maily adminovi?');
@define('INSTALL_SENDMAIL_DESC', 'Chcete dostávat e-mailem zprávy o komentářích k vašim záznamům?');
@define('INSTALL_SUBSCRIBE', 'Umožnit odběr komentářů?');
@define('INSTALL_SUBSCRIBE_DESC', 'Umožnit uživatelům přihlášení k odběru komentářů k záznamům');
@define('INSTALL_BLOGNAME', 'Název');
@define('INSTALL_BLOGNAME_DESC', 'Název vašeho weblogu');
@define('INSTALL_BLOGDESC', 'Popis');
@define('INSTALL_BLOGDESC_DESC', 'Popis weblogu');
@define('INSTALL_LANG', 'Jazyk');
@define('INSTALL_LANG_DESC', 'Vyberte jazyk vašeho weblogu');

/* Appearance and options */
@define('INSTALL_CAT_DISPLAY', 'Vzhled a volby');
@define('INSTALL_CAT_DISPLAY_DESC', 'Úprava vzhledu a chování Serendipity');
@define('INSTALL_WYSIWYG', 'Používat WYSIWYG editor?');
@define('INSTALL_WYSIWYG_DESC', 'Chcete používat WYSIWYG editor? (Pracuje v IE5+, částečně v Mozille 1.3+)');
@define('INSTALL_XHTML11', 'Vnutit kompatibilitu s XHTML 1.1?');
@define('INSTALL_XHTML11_DESC', 'Chcete plnou kompatibilitu s XHTML 1.1? (může způsobit problémy ve starších prohlížečích)');
@define('INSTALL_POPUP', 'Umožnit použití vyskakovacích oken');
@define('INSTALL_POPUP_DESC', 'Chcete ve weblogu používat vyskakovací okna pro komentáře, odezvy a pod.?');
@define('INSTALL_EMBED', 'Je Serendipity vložené?');
@define('INSTALL_EMBED_DESC', 'Pokud chcete umístit weblog do vašich stránek, zvolte ano pro odstranění všech záhlaví, bude zobrazován jen obsah. Můžete použít volitelný soubor indexFile pro obalení obsahu vlastními záhlavími a sloupci. Více informací najdete v souboru README!');
@define('INSTALL_BLOCKREF', 'Blokovaní odběratelé');
@define('INSTALL_BLOCKREF_DESC', 'Chcete zamezit přístup z určitých adres? Seznam adres oddělujte \';\' a pozor, adresy jsou blokovány včetně subadres!');
@define('INSTALL_REWRITE', 'Přepisování URL');
@define('INSTALL_REWRITE_DESC', 'Určení pravidel pro tvorbu URL. Zapnutí módu přepisování zajistí správné URL vašeho weblogu a lepší indexaci pro vyhledávače, jako je Google. Váš webserver musí podporovat mod_rewrite nebo "AllowOverride All" v adresáři pro Serendipity. Defaultní nastavení je automaticky detekováno.');

/* Imageconversion Settings */
@define('INSTALL_CAT_IMAGECONV', 'Úpravy obrázků');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Vložení základních informací o způsobu zpracování obrázků');
@define('INSTALL_IMAGEMAGICK', 'Používat Imagemagick?');
@define('INSTALL_IMAGEMAGICK_DESC', 'Máte instalován Imagemagick?');
@define('INSTALL_IMAGEMAGICKPATH', 'Cesta ke konverznímu souboru');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Úplná cesta a název konverzního souboru Imagemagick');
@define('INSTALL_THUMBSUFFIX', 'Sufix náhledů');
@define('INSTALL_THUMBSUFFIX_DESC', 'Náhledy budou pojmenovány original.sufix.ext');
@define('INSTALL_THUMBWIDTH', 'Rozměry náhledů');
@define('INSTALL_THUMBWIDTH_DESC', 'Pevná šířka automaticky generovaných náhledů');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Osobní nastavení');
@define('USERCONF_CAT_PERSONAL_DESC', 'Nastavení vašeho účtu');
@define('USERCONF_USERNAME', 'Jméno');
@define('USERCONF_USERNAME_DESC', 'Vaše uživatelské jméno (přezdívka)');
@define('USERCONF_PASSWORD', 'Heslo');
@define('USERCONF_PASSWORD_DESC', 'Vaše heslo');
@define('USERCONF_EMAIL', 'E-mailová adresa');
@define('USERCONF_EMAIL_DESC', 'Váš e-mail');
@define('USERCONF_SENDCOMMENTS', 'Posílat zprávy o komentářích?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Chcete dostávat zprávy o komentářích e-mailem?');
@define('USERCONF_SENDTRACKBACKS', 'Posílat zprávy o odezvách?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Chcete dostávat zprávy o odezvách na záznamy e-mailem?');
@define('USERCONF_ALLOWPUBLISH', 'Právo publikovat záznamy?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Umožnit uživateli publikovat záznamy');

@define('ALREADY_SUBCATEGORY', '%s je opravdu subkategorie pod %s.');
@define('PARENT_CATEGORY', 'Nadřazená kategorie');
@define('IN_REPLY_TO', 'Odpověď na');
@define('TOP_LEVEL', 'Nejvyšší úroveň');
@define('XML_IMAGE_TO_DISPLAY', 'Znak XML');
@define('XML_IMAGE_TO_DISPLAY_DESC','Odkazy na XML kanály budou zobrazeny s tímto znakem. Nechejte prázdné pro původní nastavení, nebo zadejte \'none\' pro vypnutí.');
@define('SUCCESS', 'Úspěch');

@define('POWERED_BY_SHOW_TEXT', 'Zobrazit "Serendipity" jako text');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Vytvořeno v "Serendipity" se zobrazí jako text');
@define('POWERED_BY_SHOW_IMAGE', 'Zobrazit "Serendipity" s logem');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Zobrazí se logo Serendipity');
@define('INSTALL_TOP_AS_LINKS', 'Zobrazit Top výstupy/odběratele jako linky?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"Ne": Výstupy a adresy odběratelů budou zobrazeny jako čistý text pro zamezení spamu, "Ano": nebo jako hyperlinky. "Default": Použít globální nastavení (doporučeno).');
@define('SETTINGS_SAVED_AT', 'Nové nastavení bylo uloženo v %s');
@define('PLUGIN_ITEM_DISPLAY', 'Kde by měla být tato položka zobrazena?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'V rozšířené části');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'V přehledu');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'V obou částech');

@define('RSS_IMPORT_CATEGORY', 'Použít tuto kategorii pro neurčené záznamy');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Neznámá chyba, soubor nebyl nahrán. Je možné, že délka souboru překračuje maximum, povolené serverem. Spojte se s vaším ISP nebo editujte soubor php.ini a povolte větší velikost.');
@define('COMMENTS_WILL_BE_MODERATED', 'Odeslané komentáře budou před uveřejněním moderovány.');
@define('YOU_HAVE_THESE_OPTIONS', 'Máte k dispozici tyto volby:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Pozor: Tento komentář musí být před uveřejněním odsouhlasen');
@define('DELETE_COMMENT', 'Vymazat komentář');
@define('APPROVE_COMMENT', 'Odsouhlasit komentář');
@define('REQUIRES_REVIEW', 'Vyžádat přezkoumání');
@define('COMMENT_APPROVED', 'Komentář #%s byl odsouhlasen');
@define('COMMENT_DELETED', 'Komentář #%s byl vymazán');
@define('VIEW', 'Ukázat');
@define('COMMENT_ALREADY_APPROVED', 'Komentář #%s se jeví jako skutečně odsouhlasený');
@define('COMMENT_EDITED', 'Vybraný komentář byl editován');
@define('HIDE', 'Skrýt');
@define('VIEW_EXTENDED_ENTRY', 'Pokračovat ve čtení "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Tento odkaz není míněn jako klikatelný. Obsahuje zpětné URI záznamu. Tento URI můžete použít k odesílání pingů a sledování odezvy na tento záznam. Odkaz zkopírujete kliknutím pravou myší a volbou "Kopírovat odkaz" v Internet Exploreru nebo "Zkopírovat umístění odkazu" v Mozille.');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Pozor: Tato odezva musí být před uveřejněním odsouhlasena');
@define('DELETE_TRACKBACK', 'Vymazat odezvu');
@define('APPROVE_TRACKBACK', 'Odsouhlasit odezvu');
@define('TRACKBACK_APPROVED', 'Odezva #%s byla odsouhlasena');
@define('TRACKBACK_DELETED', 'Odezva #%s byla vymazána');
@define('COMMENTS_MODERATE', 'Komentáře a odezvy k tomuto záznamu budou moderovány');
@define('PLUGIN_SUPERUSER_HTTPS', 'Použít https pro přihlášení');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Umožňuje použít spojení https pro přihlášení. Váš server to musí podporovat!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Udělat externí odkazy klikatelné?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"Ne": Neoznačené externí odkazy (Top výstupy, Top odběratelé, Uživatelské komentáře) nebudou ukázány/budou ukázány jako běžný text všude, kde je to možné, pro omezení spamu (doporučeno). "Ano": Neoznačené externí odkazy budou ukázány jako hyperlinky. Toto může být přepsáno v konfiguraci pluginů!');
@define('PAGE_BROWSE_COMMENTS', 'Stránka %s ze %s, celkem %s komentářů');
@define('FILTERS', 'Filtry');
@define('FIND_ENTRIES', 'Hledat záznamy');
@define('FIND_COMMENTS', 'Hledat komentáře');
@define('FIND_MEDIA', 'Hledat média');
@define('FILTER_DIRECTORY', 'Adresář');
@define('SORT_BY', 'Seřadit podle');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Odezva nebyla odeslána: nepodařilo se spojení s %s na portu %d');
@define('MEDIA', 'Média (obrázky)');
@define('MEDIA_LIBRARY', 'Knihovna médií');
@define('ADD_MEDIA', 'Přidat');
@define('ENTER_MEDIA_URL', 'Vložte URL přidávaného souboru:');
@define('ENTER_MEDIA_UPLOAD', 'Vyberte soubor pro nahrání:');
@define('SAVE_FILE_AS', 'Uložit soubor jako:');
@define('STORE_IN_DIRECTORY', 'Uložit do následujího adresáře: ');
@define('MEDIA_RENAME', 'Přejmenovat soubor');
@define('IMAGE_RESIZE', 'Změnit rozměr obrázku');
@define('MEDIA_DELETE', 'Vymazat soubor');
@define('FILES_PER_PAGE', 'Souborů na stránku');
@define('CLICK_FILE_TO_INSERT', 'Klikněte na soubor, který chcete vložit:');
@define('SELECT_FILE', 'Vyberte soubor pro vložení:');
@define('MEDIA_FULLSIZE', 'Plný rozměr');
@define('CALENDAR_BOW_DESC', 'Den, určený jako začátek týdne. Default je pondělí');
@define('ALLOWS_YOU_BLAHBLAH', 'Vložit odkaz do postranního bloku administrace weblogu');
@define('CALENDAR', 'Kalendář');
@define('SUPERUSER_OPEN_ADMIN', 'Administrace');
@define('SUPERUSER_OPEN_LOGIN', 'Přihlášení');
@define('INVERT_SELECTIONS', 'Obrátit výběr');
@define('COMMENTS_DELETE_CONFIRM', 'Jste se jist vymazáním vybraných komentářů?');
@define('COMMENT_DELETE_CONFIRM', 'Jste si jist vymazáním komentáře #%d, zapsaného %s?');
@define('DELETE_SELECTED_COMMENTS', 'Vymazat vybrané komentáře');
@define('VIEW_COMMENT', 'Ukázat komentář');
@define('VIEW_ENTRY', 'Ukázat záznam');
@define('DELETE_FILE', 'Vymazat soubor s názvem <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'Chcete vymazat <b>%s</b><br />Jestliže používáte tento soubor v nějakých záznamech, způsobí to nepřístupnost odkazů nebo obrázků.<br />Chcete přesto pokračovat?<br /><br />');
@define('TRACKBACK_SENDING', 'Odeslání odezvy na URI %s...');
@define('TRACKBACK_SENT', 'Odezva úspěšná');
@define('TRACKBACK_FAILED', 'Odezva neúspěšná: %s');
@define('TRACKBACK_NOT_FOUND', 'URI odezvy neexistuje.');
@define('TRACKBACK_URI_MISMATCH', 'Automaticky získané URI neodpovídá vašemu cílovému.');
@define('TRACKBACK_CHECKING', 'Testvání <u>%s</u> pro možné odezvy...');
@define('TRACKBACK_NO_DATA', 'Cíl neobsahuje data');
@define('TRACKBACK_SIZE', 'Cílové URI překročilo max. velikost souboru %s bytů.');
@define('VIEWMODE_THREADED', 'Přepnout na vláknové zobrazení');
@define('COMMENTS_VIEWMODE_THREADED', 'Vláknové');
@define('COMMENTS_VIEWMODE_LINEAR', 'Lineární');
@define('DISPLAY_COMMENTS_AS', 'Zobrazit komentáře jako');
@define('ADD_MEDIA_BLAHBLAH', '<b>Přidat soubor do schránky médií:</b><p>Zde můžete ukládat mediální soubory, nebo určit, kde je získat z WEBu! Pokud nemáte odpovídající obrázek, <a href="http://images.google.com" target="_blank">hledejte na Google</a> odpověď na vaši potřebu, obvykle se zadaří :).<p><b>Vyberte metodu:</b><br>');
@define('COMMENTS_FILTER_SHOW', 'Zobrazit');
@define('COMMENTS_FILTER_ALL', 'Vše');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Pouze povolené');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Čekající na povolení');
@define('RSS_IMPORT_BODYONLY', 'Uložit celý importovaný text do "hlavní" části, nerozdělovat do "rozšířené" části.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Zobrazit celé články včetně rozšířené části v RSS kanálu');
@define('MT_DATA_FILE', 'Soubory Movable Type');
@define('FORCE', 'Vnutit');
@define('CREATE_AUTHOR', 'Vytvořit autora \'%s\'.');
@define('CREATE_CATEGORY', 'Vytvořit kategorii \'%s\'.');
@define('MYSQL_REQUIRED', 'Pro provedení této akce je nutné mít databázi MySQL.');
@define('COULDNT_CONNECT', 'Nebylo možné se spojit s databází MySQL: %s.');
@define('COULDNT_SELECT_DB', 'Nebylo možné vybrat databázi: %s.');
@define('COULDNT_SELECT_USER_INFO', 'Nebylo možné vybrat uživatelské informace: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'Nebylo možné vybrat informace o kategorii: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'Nebylo možné vybrat informace o záznamu: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'Nebylo možné vybrat informace o komentáři: %s.');
@define('WEEK', 'Týden');
@define('WEEKS', 'Týdny');
@define('MONTHS', 'Měsíce');
@define('DAYS', 'Dny');
@define('ARCHIVE_FREQUENCY', 'Kalendářní krok');
@define('ARCHIVE_FREQUENCY_DESC', 'Kalendářní krok mezi prvky seznamu');
@define('ARCHIVE_COUNT', 'Počet prvků v seznamu');
@define('ARCHIVE_COUNT_DESC', 'Celkový počet zobrazených měsíců, týdnů nebo dnů');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Níže je seznam instalovaných pluginů');
@define('SIDEBAR_PLUGIN', 'postranní plugin');
@define('EVENT_PLUGIN', 'plugin události');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Klikněte a instalujte nový %s');
@define('VERSION', 'verze');
@define('INSTALL', 'Instalovat');
@define('ALREADY_INSTALLED', 'Instalován');
@define('SELECT_A_PLUGIN_TO_ADD', 'Vyberte plugin, který chcete instalovat');
@define('INSTALL_OFFSET', 'Časový posun serveru');
@define('STICKY_POSTINGS', 'Přilepené záznamy');
@define('INSTALL_FETCHLIMIT', 'Záznamy zobrazené na hlavní stránce');
@define('INSTALL_FETCHLIMIT_DESC', 'Počet záznamů, zobrazených na hlavní stránce');
@define('IMPORT_ENTRIES', 'Import dat');
@define('EXPORT_ENTRIES', 'Export záznamů');
@define('IMPORT_WELCOME', 'Vítejte v utilitě pro import dat');
@define('IMPORT_WHAT_CAN', 'Zde můžete importovat záznamy z jiných weblogů');
@define('IMPORT_SELECT', 'Vyberte software, ze kterého chcete importovat');
@define('IMPORT_PLEASE_ENTER', 'Vložte data požadovaná níže');
@define('IMPORT_NOW', 'Importovat!');
@define('IMPORT_STARTING', 'Start importu...');
@define('IMPORT_FAILED', 'Import se nezdařil');
@define('IMPORT_DONE', 'Import úspěšně dokončen');
@define('IMPORT_WEBLOG_APP', 'Weblogová aplikace');
@define('EXPORT_FEED', 'Exportovat plný RSS kanál');
@define('STATUS', 'Stav po importu');
@define('IMPORT_GENERIC_RSS', 'Základní RSS import');
@define('ACTIVATE_AUTODISCOVERY', 'Odeslat odezvy na odkazy obsažené v záznamu');
@define('WELCOME_TO_ADMIN', 'Vítejte v Administrační sekci Serendipity .');
@define('PLEASE_ENTER_CREDENTIALS', 'Vložte oprávnění.');
@define('ADMIN_FOOTER_POWERED_BY', 'Vytvořeno pomocí Serendipity %s a PHP %s');
@define('INSTALL_USEGZIP', 'Použijte kompresi gzip');
@define('INSTALL_USEGZIP_DESC', 'Doporučujeme použít kompresi stránek pro jejich urychlené načítání');
@define('INSTALL_SHOWFUTURE', 'Zobrazit budoucí záznamy');
@define('INSTALL_SHOWFUTURE_DESC', 'Tato volba umožní zobrazení budoucích záznamů blogu. Defaultně jsou skryté a budou zobrazeny až v čase jejich vydání.');
@define('INSTALL_DBPERSISTENT', 'Použít trvalé připojení');
@define('INSTALL_DBPERSISTENT_DESC', 'Umožnit trvalé připojení k databázi, více <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">zde</a>. Běžně to není doporučeno');
@define('NO_IMAGES_FOUND', 'Žádné obrázky');
@define('PERSONAL_SETTINGS', 'Osobní nastavení');
@define('REFERER', 'Odběratel');
@define('NOT_FOUND', 'Není obsažen');
@define('NOT_WRITABLE', 'Nezapisovatelný');
@define('WRITABLE', 'Zapisovatelný');
@define('PROBLEM_DIAGNOSTIC', 'Byly diagnostikovány problémy, takže nelze pokračovat v instalaci, dokud nebudou odstraněny');
@define('SELECT_INSTALLATION_TYPE', 'Vyberte typ instalace');
@define('WELCOME_TO_INSTALLATION', 'Vítejte v instalaci Serendipity');
@define('FIRST_WE_TAKE_A_LOOK', 'Nejdříve se podíváme na vaše základní nastavení a zkusíme diagnostikovat případné problémy');
@define('ERRORS_ARE_DISPLAYED_IN', 'Chyby budou zobrazeny %s, doporučení %s a úspěch %s');
@define('RED', 'červeně');
@define('YELLOW', 'žlutě');
@define('GREEN', 'zeleně');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s - předinstalační zpráva');
@define('RECOMMENDED', 'Doporučeno');
@define('ACTUAL', 'Aktuální');
@define('PHPINI_CONFIGURATION', 'konfigurace php.ini');
@define('PHP_INSTALLATION', 'Instalace PHP');
@define('THEY_DO', 'they do');
@define('THEY_DONT', 'they don\'t');
@define('SIMPLE_INSTALLATION', 'Jednoduchá instalace');
@define('EXPERT_INSTALLATION', 'Expertní instalace');
@define('COMPLETE_INSTALLATION', 'Kompletní instalace');
@define('WONT_INSTALL_DB_AGAIN', 'nechci znovu instalovat databázi');
@define('CHECK_DATABASE_EXISTS', 'Kontrola, jestli databáze a tabulky opravdu existují');
@define('CREATING_PRIMARY_AUTHOR', 'Vytvoření hlavního autora \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Nastavení defaultního vzoru');
@define('INSTALLING_DEFAULT_PLUGINS', 'Instalace defaultních pluginů');
@define('SERENDIPITY_INSTALLED', 'Serendipity byl úspěšně nainstalován');
@define('VISIT_BLOG_HERE', 'Zde se přepnete do svého nového weblogu');
@define('THANK_YOU_FOR_CHOOSING', 'Děkujeme za volbu Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'Při instalaci byla detekována chyba');
@define('OPERATING_SYSTEM', 'Operační systém');
@define('WEBSERVER_SAPI', 'Webserver SAPI');
@define('IMAGE_ROTATE_LEFT', 'Otočit o 90 stupňů doleva');
@define('IMAGE_ROTATE_RIGHT', 'Otočit o 90 stupňů doprava');
@define('TEMPLATE_SET', '\'%s\' byl nastaven jako defaultní vzor (template)');
@define('SEARCH_ERROR', 'Funkce vyhledávání nepracovala podle očekávání. Poznámka pro administrátora blogu: Mohlo to být způsobeno nepřítomností příslušných indexů v databázi. Uživatelský účet v databázi MySQL musí být oprávněn vykonat tento dotaz: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> Specifická chyba vrácená databází byla: <pre>%s</pre>');
@define('EDIT_THIS_CAT', 'Editace "%s"');
@define('CATEGORY_REMAINING', 'Vymazat kategorii a přemístit záznamy do kategorie');
@define('CATEGORY_INDEX', 'Níže je seznam kategorií, které můžet použít k vašemu záznamu');
@define('NO_CATEGORIES', 'Žádné kategorie');
@define('RESET_DATE', 'Resetovat datum');
@define('RESET_DATE_DESC', 'Klikněte a resetujte datum na aktuální');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Oprávnění může být nastaveno s použitím povelu: `<em>%s</em>` v adresáři, nebo nastavením pomocí FTP programu');
@define('WARNING_TEMPLATE_DEPRECATED', 'Varování: Váš vzor používá nepovolenou metodu, je-li to možné, proveďte aktualizaci');
@define('ENTRY_PUBLISHED_FUTURE', 'Tento záznam ještě není publikován.');
@define('ENTRIES_BY', 'Záznamy od %s');
@define('PREVIOUS', 'Předchozí');
@define('NEXT', 'Další');
@define('APPROVE', 'Povolit');
@define('DO_MARKUP_DESCRIPTION', 'Převést značky na text (smajlíky, zkratky *, /, _, ...). Vypnutí této volby zajistí uložení HTML kódů v textu.');
@define('CATEGORY_ALREADY_EXIST', 'Kategorie nazvaná "%s" skutečně existuje');
@define('IMPORT_NOTES', 'Poznámka:');
@define('ERROR_FILE_FORBIDDEN', 'Nejste oprávněn nahrávat soubory s aktivním obsahem');
@define('ADMIN', 'Administrace');
@define('ADMIN_FRONTPAGE', 'Hlavní stránka');
@define('QUOTE', 'Citace');
@define('IFRAME_SAVE', 'Serendipity ukládá váš záznam, vytváří odezvy a zajišťuje možná XML-RPC spojení. Může to chvíli trvat...');
@define('IFRAME_SAVE_DRAFT', 'Koncept tohoto záznamu byl uložen');
@define('IFRAME_PREVIEW', 'Serendipity nyní vytváří náhled vašeho záznamu...');
@define('IFRAME_WARNING', 'Váš prohlížeč nepodporuje iframe. Otevřete soubor serendipity_config.inc.php a nastavte proměnnou $serendipity[\'use_iframe\'] na FALSE.');
@define('NONE', 'nic');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Základní nastavení pro nové záznamy');
@define('UPGRADE', 'Aktualizace');
@define('UPGRADE_TO_VERSION', 'Aktualizace na verzi %s');
@define('DELETE_DIRECTORY', 'Vymazat adresář');
@define('DELETE_DIRECTORY_DESC', 'Chcete vymazat obsah adresáře, obsahující mediální soubory, které mohou být používány ve vašich záznamech.');
@define('FORCE_DELETE', 'Vymazat VŠECHNY soubory v adresáři, včetně těch, které nejsou vytvořeny pomocí Serendipity');
@define('CREATE_DIRECTORY', 'Vytvořit adresář');
@define('CREATE_NEW_DIRECTORY', 'Vytvořit nový adresář');
@define('CREATE_DIRECTORY_DESC', 'Zde můžete vytvořit adresář pro ukládání mediálních souborů. Zvolte název adresáře a případný nadřízený adresář.');
@define('BASE_DIRECTORY', 'Základní adresář');
@define('USERLEVEL_EDITOR_DESC', 'Autor');
@define('USERLEVEL_CHIEF_DESC', 'Redaktor');
@define('USERLEVEL_ADMIN_DESC', 'Administrátor');
@define('USERCONF_USERLEVEL', 'Úroveň');
@define('USERCONF_USERLEVEL_DESC', 'Tato úroveň určuje práva uživatele weblogu.');
@define('USER_SELF_INFO', 'Přihlášen jako %s (%s)');
@define('ADMIN_ENTRIES', 'Záznamy');
@define('RECHECK_INSTALLATION', 'Překontrolovat instalaci');
@define('IMAGICK_EXEC_ERROR', 'Nelze spustit: "%s", chyba: %s, vrací proměnnou: %d');
@define('INSTALL_OFFSET_DESC', 'Vložte počet hodin mezi časem serveru (aktuálně: %clock%) a vaší časovou zónou');
@define('UNMET_REQUIREMENTS', 'Nesplněné požadavky: %s');
@define('CHARSET', 'Znaková sada');
@define('AUTOLANG', 'Použít jazyk prohlížeče jako defaultní');
@define('AUTOLANG_DESC', 'Zapnutím této volby určíte, že jazyk prohlížeče bude převzat jako základní pro uživatelské rozhraní a pro záznamy.');
@define('INSTALL_AUTODETECT_URL', 'Autodetekce použité HTTP hostitelské adresy');
@define('INSTALL_AUTODETECT_URL_DESC', 'Při volbě "Ano" bude Serendipity předpokládat, že HTTP adresa hostitele, použitá návštěvníkem, je vaše základní nastavení URL. Zapnutí umožní používání různých domén k přístupu na vaše stránky, a použití této jedné domény pro všechny odkazy ke sledování změn na stránkách.');
@define('CONVERT_HTMLENTITIES', 'Zkusit automatickou konverzi HTML entit?');
@define('EMPTY_SETTING', 'Nespecifikoval jste platnou hodnotu pro "%s"!');
@define('USERCONF_REALNAME', 'Skutečné jméno');
@define('USERCONF_REALNAME_DESC', 'Plné jméno autora. Toto jméno uvidí čtenáři');
@define('HOTLINK_DONE', 'Soubor připojen odkazem.<br />Hotovo.');
@define('ENTER_MEDIA_URL_METHOD', 'Způsob připojení:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Poznámka: Pokud zvolíte odkaz na server, ujistěte se, že máte potřebná práva, nebo že jde o váš web. Odkazy vám umožní využívat obrázky z jiných než místních zdrojů.');
@define('MEDIA_HOTLINKED', 'odkazován');
@define('FETCH_METHOD_IMAGE', 'Nahrání na server');
@define('FETCH_METHOD_HOTLINK', 'Odkaz na server');
@define('DELETE_HOTLINK_FILE', 'Vymazán odkazovaný soubor <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Zobrazovat e-mailové adresy?');
@define('IMAGE_MORE_INPUT', 'Přidat více obrázků'); 
@define('BACKEND_TITLE', 'Další informace v konfigurační obrazovce pluginu');
@define('BACKEND_TITLE_FOR_NUGGET', 'Zde můžete definovat svůj řetězec, který bude zobrazen v konfigurační obrazovce pluginu společně s popisem pluginu HTML Nugget. Když máte několik HTML nuggetů s prázdným tittle, toto vám pomůže je rozlišit.'); 
@define('CATEGORIES_ALLOW_SELECT', 'Povolit návštěvníkům zobrazit více kategorií najednou?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Jestliže je tato volba povolena, bude v tomto postranním pluginu hned vedle každé kategorie zaškrtávací okénko. Uživatelé mohou tyto boxy zaškrtnout a vidět jen příspěvky patřící do tohoto výběru.'); 
@define('PAGE_BROWSE_PLUGINS', 'Strana %s z %s, celkem %s pluginů.');
@define('INSTALL_CAT_PERMALINKS', 'Trvalé odkazy');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Definuje různé vzory  URL patterns pro definici trvalých odkazů (permanent links) ve vašem blogu. Doporučujeme použít defaultní nastavení; pokud ne, měli byste zkusit použít hodnotu %id% tam, kde je to možné, abyste předešli dotazům do databáze při hledání cílové URL.');
@define('INSTALL_PERMALINK', 'Struktura URL trvalých odkazů');
@define('INSTALL_PERMALINK_DESC', 'Zde můžete definovat relativní strukturu URL, kde začátek je vaše base URL, z níž mohou být  příspěvky dostupné. Můžete použít proměnné  %id%, %title%, %day%, %month%, %year% a jakékoli jiné znaky.');
@define('INSTALL_PERMALINK_AUTHOR', 'Struktura URL autorů');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Zde můžete definovat relativní strukturu URL, kde začátek je vaše base URL, z níž mohou být dostupné příspěvky určitých autorů.  Můžete použít proměnné %id%, %realname%, %username%, %email% a jakékoli jiné znaky.');
@define('INSTALL_PERMALINK_CATEGORY', 'Struktura URL kategorií');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Zde můžete definovat relativní strukturu URL, kde začátek je vaše base URL, z níž mohou být dostupné určité kategorie. Můžete použít proměnné  %id%, %name%, %description% a jakékoli jiné znaky.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Struktura URL trvalých odkazů kategorií RSS');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Zde můžete definovat relativní strukturu URL, kde začátek je vaše base URL, z níž mohou být dostupné  RSS kanály z určitých kategorií. Můžete použít proměnné %id%, %name%, %description% a jakékoli jiné znaky.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Cesta k archivům');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Cesta k archivu');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Cesta ke kategoriím');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Cesta k odhlášení komentářů');
@define('INSTALL_PERMALINK_DELETEPATH', 'Cesta pro smazání komentářů');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Cesta ke schválení komentářů');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Cesta k RSS');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Cesta k jednotlivému pluginu');
@define('INSTALL_PERMALINK_ADMINPATH', 'Cesta k adminu');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Cesta k vyhledávání');
@define('INSTALL_CAL', 'Typ kalendáře');
@define('INSTALL_CAL_DESC', 'Vyberte formát kalendáře');
@define('REPLY', 'Odpověď');
@define('USERCONF_GROUPS', 'Členství ve skupinách');
@define('USERCONF_GROUPS_DESC', 'Tento uživatel je člen následujících skupin. členství ve více skupinách je možné.');
@define('MANAGE_GROUPS', 'Upravuj skupiny');
@define('DELETED_GROUP', 'Skupina #%d %s smazána.');
@define('CREATED_GROUP', 'Nová skupina %s byla vytvořena');
@define('MODIFIED_GROUP', 'Vlastnosti skupiny %s byly změněny');
@define('GROUP', 'Skupina');
@define('CREATE_NEW_GROUP', 'Vytvořit novou skupinu');
@define('DELETE_GROUP', 'Chystáte se smazat skupinu #%d %s. Myslíte to vážně?');
@define('USERLEVEL_OBSOLETE', 'UPOZORNĚNÍ: Atribut úroveň uživatele (userlevel) je nyní používán jen kvůli zpětné kompatibilitě s pluginy a autorizaci. Uživatelská práva jsou nyní řízena pomocí členských skupin!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'ID feedu, který chcete publikovat');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner image');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Název obrázku, který se má zobrazit (nebo prázdný pro počitadlo), umístěné na  feedburner.com, např: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner title');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Title (je-li), který se má zobrazit u obrázku');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner image text');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Text (je-li) který se má zobrazit při najetí na obrázek');
@define('SEARCH_TOO_SHORT', 'Vyhledávací dotaz musí být delší než 3 znaky. Ke kratším slovům můžete zkusit přidat *, jako: s9y*, abyste  vyhledávání přiměli pracovat s kratšími slovy.');
@define('INSTALL_DBPORT', 'Database port');
@define('INSTALL_DBPORT_DESC', 'Port použitý pro spojení k vašemu databázovému serveru');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Viditelné (Frontend): Externí služby');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Viditelné (Frontend): Další možnosti');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Viditelné (Frontend): Úplné mody');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Viditelné (Frontend): Zobrazení/filtry');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Viditelné (Frontend): Pluginy pro příspěvky');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Provozní (Backend): Editor');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Provozní (Backend): Řízení uživatelů');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Provozní (Backend): Meta informace');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Provozní (Backend): Templates - šablony vzhledu');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Provozní (Backend): Další možnosti');
@define('PLUGIN_GROUP_IMAGES', 'Obrázky');
@define('PLUGIN_GROUP_ANTISPAM', 'Antispam');
@define('PLUGIN_GROUP_MARKUP', 'Markup - textové značky');
@define('PLUGIN_GROUP_STATISTICS', 'Statistiky');
@define('PERMISSION_PERSONALCONFIGURATION', 'osobníKonfigurace: Přístup k osobní konfiguraci');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'osobníKonfiguraceÚroveňUživatele: Změnit úroveň uživatele (level)');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'osobníKonfiguraceNeNové: Změnit "zákaz nových příspěvků"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'osobníKonfiguracePrávoPublikovat: Změnit právo na publikování příspěvků');
@define('PERMISSION_SITECONFIGURATION', 'webKonfigurace: Konfigurace  přístupu');
@define('PERMISSION_BLOGCONFIGURATION', 'blogKonfigurace: Konfigurace přístupu k  blogu');
@define('PERMISSION_ADMINENTRIES', 'adminPříspěvky: Administrace příspěvků');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminÚdržbaPříspěvkůOstatních: Administrace příspěvků ostatních uživatelů');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Import příspěvků');
@define('PERMISSION_ADMINCATEGORIES', 'adminKategorie: Administrace kategorií');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminÚdržbaKategoriíOstatních: Administrace kategorií ostatních uživatelů');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminMazáníKategorií: Smazat kategorie');
@define('PERMISSION_ADMINUSERS', 'adminUživatelů: Administrace uživatelů');
@define('PERMISSION_ADMINUSERSDELETE', 'adminMazáníUživatelů: Smazat uživatele');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminZměnaÚrovněUživatele: Změna úrovně uživatele');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUživateléStejnéSkupiny: Administrace uživatelů ve stejné skupině');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUživateléJinéSkupiny: Administrace uživatelů v jiných skupinách');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminNovíUživatelé: Zakládat nové uživatele');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUživatelskéSkupiny: Administrace skupin uživatelů');
@define('PERMISSION_ADMINPLUGINS', 'adminPluginy: Administrace pluginů');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminÚdržbaPluginůOstatních: Administrace pluginů ostatních uživatelů');
@define('PERMISSION_ADMINIMAGES', 'adminObrázky: Administrace souborů  media');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminAdresářeObrázků: Administrace adresářů pro media');
@define('PERMISSION_ADMINIMAGESADD', 'adminPřidatObrázek: Přidávání nových souborů medií');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminSmazatObrázek: Mazání souborů medií');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminÚdržbaObrázkůOstatní: Administrace souborů medií ostatních uživatelů');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminProhlíženíObrázků: Prohlížení souborů medií');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminSynchroObrázků: Sync thumbnailů');
@define('PERMISSION_ADMINCOMMENTS', 'adminKomentáře: Administrace komentářů');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplate: Administrace šablon (template)');
@define('INSTALL_BLOG_EMAIL', 'E-Mail pro blog');
@define('INSTALL_BLOG_EMAIL_DESC', 'Toto nastaví E-Mailovou adresu, která je použita v poli "From"- (od) pro odchozí e-maily. Nastavte si tuto adresu tak, aby byla rozpoznána mailovým serverem používaným vaším webhosterem - mnoho mailserverů odmítá poštu, která má neznámou From-addresu (adr odesilatele).');
@define('CATEGORIES_PARENT_BASE', 'Zobrazit jen kategorie niže ...');
@define('CATEGORIES_PARENT_BASE_DESC', 'Můžete vybrat rodičovskou kategorii, takže budou zobrazeny jen její nižší kategori.');
@define('CATEGORIES_HIDE_PARALLEL', 'Skrýt kategorie, které nejsou součástí stromu kategorií');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Jestliže chcete skrýt kategorie, které jsou částí jiného stromu kategorií, musíte tohle povolit. Tato možnost se nejlépe  použije ve spojení s multi-blogem a pluginem  "Properties/Templates of categories".');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminProhlíženíObrázkůOstatní: Prohlížení medií ostatních uživatelů');
@define('CHARSET_NATIVE', 'Národní');
@define('INSTALL_CHARSET', 'Volba znakové sady - Charset');
@define('INSTALL_CHARSET_DESC', 'Zde můžete volit mezi UTF-8 nebo národní (ISO, EUC, ...) znakovou sadou. Některé jazyky mají jen překlady UTF-8, takže nastavení znakové sady na národní nemá žádný účinek. UTF-8 se doporučuje pro nové instalace. Neměňte toto nastavení, jestliže jste již  napsali příspěvky se speciálními (národními) znaky - mohlo by způsobit porušení textu. Přečtěte si o tomto problému více na  http://www.s9y.org/index.php?node=46 .');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Povolit Plugin API hook');
@define('CALENDAR_EXTEVENT_DESC', 'Jestliže je toto povoleno, mohou se pluginy napojovat na kalendář a zvýrazňovat své vlastní události. Povolte jen když máte pluginy, které toto potřebují, jinak to jen snižuje výkon.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'XML-RPC API Interface na Serendipity již není přibaleno  kvůli pokračujícím bezpečnostním problémům s tímhle API a protože ho moc lidí nepoužívá. Proto musíte nainstalovat plugin XML-RPC, když chcete  XML-RPC API používat. URL, které se použije ve vaší aplikaci, se nezmění - hned po instalaci pluginu budete moci API používat.');
@define('PERM_READ', 'Právo na čtení');
@define('PERM_WRITE', 'Právo na zápis');

@define('PERM_DENIED', 'Přístup odepřen.');
@define('INSTALL_ACL', 'Aplikovat práva na čtení pro kategorie');
@define('INSTALL_ACL_DESC', 'Pokud je povoleno, budou na kategorie aplikována nastavení práv pro skupiny uživatelů, když si přihlášení uživatelé budou prohlížet váš blog. Není-li povoleno, práva na čtení pro kategorie nejsou aplikována,  a  zlepšuje se rychlost blogu. Jestliže nechcete mít práva pro čtení pro různé uživatele,  toto nastavení zakažte.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Syntax konfigurace je chybná pro volbu "%s". Vyžaduje obsah typu "%s".');
@define('USERCONF_CHECK_PASSWORD', 'Staré heslo');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Jestliže změníte  heslo v políčku výše, musíte do tohoto pole zadat současné heslo.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'Nezadali jste správné staré heslo a nejste oprávněni heslo změnit. Vaše nastavení nebylo uloženo.');
@define('ERROR_XSRF', 'Váš prohlížeč nezaslal platný  HTTP-Referrer string. To mohlo být způsobeno buď špatně nastaveným prohlížečem/proxy nebo  Cross Site Request Forgery (XSRF), který je na vás namířen. Požadovaná akce nemohla být dokončena.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Zde můžete definovat relativní strukturu URL, kde začátek je vaše base URL, z níž mohou být být dostupné RSS kanály od určitých uživatelů. Můžete použít proměnné   %id%, %realname%, %username%, %email% a jakékoli jiné znaky.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Permalink RSS-Feed Author URL structure');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'Cesta k autorům');
@define('AUTHORS', 'Autoři');
@define('AUTHORS_ALLOW_SELECT', 'Povolit návštěvníkům vybrat více autorů najednou?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Jestliže je tato volba povolena, bude u každého autora umístěno zatrhávací okénko. Uživatelé mohou zvolit více autorů  a vidět příspěvky, které vyhovují jejich výběru');
@define('AUTHOR_PLUGIN_DESC', 'Zobrazit seznam autorů');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Povolit Smarty-Templates?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Je-li tato možnost povolena, bude plugin pro výpis kategorií využívat možností  Smarty-Templating. Když tohle povolíte, můžete měnit layout přes šablonu "plugin_categories.tpl". Povolení téhle volby může zhoršit výkon, takže pokud nechcete dělat úpravy pro jednotlivé kategorie, nechte to zakázané.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Zobrazit počet příspěvků na kategorii? ');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Zobrazit počet článků u jména autora?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Je-li tato volba povolena, je vedle jména autora zobrazen v závorce počet jeho příspěvků.');
@define('CUSTOM_ADMIN_INTERFACE', 'Je upravené prostředí pro administraci');

@define('COMMENT_NOT_ADDED', 'Váš komentář nemohl být přidán, protože komentáře k tomuto příspěvku byly zakázány, zadali jste špatná data nebo byl váš komentář zachycen antispamem.');
@define('INSTALL_TRACKREF', 'Povolit  referrer tracking?');
@define('INSTALL_TRACKREF_DESC', 'Povolení referrer tracking vám ukáže, které weby odkazují na vaše články. Dnes je to často zneužíváno pro spam, takže to můžete zakázat, chcete-li.');
@define('CATEGORIES_HIDE_PARENT', 'Skrýt zvolenou rodičovskou kategorii?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Jestliže omezíte výpis kategorií na specifickou kategorii,  standardně bude  na výstupu rodičovská kategorie zobrazena. Když tuto možnost zakážete, název rodičovské kategorie nebude zobrazen.');
@define('WARNING_NO_GROUPS_SELECTED', 'Varování: Nezvolili jste si členství v žádné skupině. To by vás vyloučilo z řízení práv uživatelských skupin, a proto vaše členství ve skupině nebude změněno.');
@define('INSTALL_RSSFETCHLIMIT', 'Články, které se mají zobrazit v RSS Feedu');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Počet článků, které se má zobrazit na každé stránce  v RSS Feedu.');
@define('INSTAL_DB_UTF8', 'Povolit DB-charset conversion');
@define('INSTAL_DB_UTF8_DESC', 'Vyvolá dotaz MySQL "SET NAMES", aby se zjistila požadovaná znaková sada pro databázi. Zapněte to nebo vypněte, pokud se vám na blogu objevují  podivné znaky.');
@define('ONTHEFLYSYNCH', 'Povolit synchronizaci medií za běhu (on the fly)');
@define('ONTHEFLYSYNCH_DESC', 'Pokud je to povoleno, Serendipity bude porovnávat databázi medií se soubory uloženými na serveru a bude synchronizovat obsah databáze a adresáře.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'Jméno uživatele nemůže být prázdné.');
@define('FURTHER_LINKS', 'Další odkazy');
@define('FURTHER_LINKS_S9Y', 'Serendipity Homepage');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Documentation');
@define('FURTHER_LINKS_S9Y_BLOG', 'Official Blog');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Komentář odstraněn)');

@define('CURRENT_AUTHOR', 'Aktuální autor');

@define('WORD_NEW', 'Nové');
@define('SHOW_MEDIA_TOOLBAR', 'Ukázat lištu nástrojů v okně výběru medií?');
@define('MEDIA_KEYWORDS', 'Media - klíčová slova');
@define('MEDIA_KEYWORDS_DESC', 'Zadejte seznam slov oddělených  ";" která chcete použít jako předdefonovaná klíčová slova pro položky v mediích.');
@define('MEDIA_EXIF', 'Importovat EXIF/JPEG  data obrázku');
@define('MEDIA_EXIF_DESC', 'Je-li povoleno, existující EXIF/JPEG metadata obrázků budou parsována a uložena v databázi, aby je bylo možno zobrazit v galerii medií.');
@define('MEDIA_PROP', 'Vlastnosti media');


@define('GO_ADD_PROPERTIES', 'Zadej vlastnosti');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', 'Krátký komentář');
@define('MEDIA_PROPERTY_COMMENT2', 'Dlouhý komentář');
@define('MEDIA_PROPERTY_TITLE', 'Titulek');
@define('MEDIA_PROP_DESC', 'Zadejte seznam polí vlastností oddělených  ";" , které chcete definovat pro každý souor v mediích');
@define('MEDIA_PROP_MULTIDESC', '(Za každou položku můžete přidat ":MULTI", což bude indikovat, že tato položka bude obsahovat dlouhý text místo jen několika znaků)');

@define('STYLE_OPTIONS_NONE', 'Toto téma/styl nemá specifické volby. Pokud chcete vědět, jak můžete pro svoje šablony nastavit specifické volby, čtěte Technical Documentation na www.s9y.org  "Configuration of Theme options".');
@define('STYLE_OPTIONS', 'Volby pro téma/stylu');

@define('PLUGIN_AVAILABLE_COUNT', 'Celkem: %d pluginů.');

@define('SYNDICATION_RFC2616', 'Aktivovat strict RFC2616 RSS-Feed compliance');
@define('SYNDICATION_RFC2616_DESC', 'Když neaktivujete  RFC2616, znamená to, že všechny podmíněné GETy na Serendipity vrátí příspěvky, které byly modifikovány od času posledního požadavku. Když tohle nastavíte na  "false", vaši návštěvníci dostanou všechny články od svého posledního požadavku, což se považuje za dobrou věc. Avšak někteří agenti jako  Planet fungují divně, když tohle nastane a taky to porušuje  RFC2616. Takže když nastavíte tuto volbu na  "TRUE", budete vyhovovat RFC ale návštěvníkům   mohou ve  čtečkách  během prázdnin zmizet příspěvky. V každém případě, buď to vadí agregátorům jako je  Planet, nebo to vadí návštěvníkům blogu. Když se vyskytnou stížnosti z kterékoli strany, můžete tuhle volbu přepnout.  Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Asociované datum');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
@define('FILENAME_REASSIGNED', 'Automaticky přidělené nové jméno souboru: %s');
@define('MEDIA_UPLOAD_SIZE', 'Max. velikost uploadvoaného souboru');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Zadejte maximální velikost pro uploadované (nahrávané) soubory v bytech. Toto nastavení může být  přepsáno nastavením serveru v php.ini: upload_max_filesize, post_max_size, max_input_time mají přednost před touto volbou. Prázdný řetězec znamená, že se použije limit serveru.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Chyba: Nemůžete uploadovat soubory větší než  %s bytů!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. šířka obrázků pro upload');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Zadejte maximální šířku pro uploadované obrázky v pixelech.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. výška obrázku pro upload');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Zadejte maximální výšku v pixelech pro uploadované obrázky.');
@define('MEDIA_UPLOAD_DIMERROR', 'Chyba: Nemůžete uploadovat soubory obrázků větší než  %s x %s pixelů!');

@define('MEDIA_TARGET', 'Cíl odkazu');
@define('MEDIA_TARGET_JS', 'Popup okno (pomocí JavaScriptu, přizpůsobitelná velikost)');
@define('MEDIA_ENTRY', 'Samostatný příspěvek');
@define('MEDIA_TARGET_BLANK', 'Popup okno (pomocí target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Povolit dynamickou změnu velikosti obrázků?');
@define('MEDIA_DYN_RESIZE_DESC', 'Je-li povoleno, může  media selector vracet obrázky v jakékoli požadované velikosti přes proměnnou  GET. Výsledky jsou kešovány, a tak se může vytvořit velký soubor, jestliže to intenzivně používáte.');

@define('MEDIA_DIRECTORY_MOVED', 'Adresáře a soubory byly úspěšně přesunuty do  %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Adresáře a soubory nemohly být přesunuty do  %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'V Ne-MySQL databázi není iterace po příspěvcích a nahrazení staré adresy původního adresáře novou URL možné. Budete muset příspěvky ručně editovat a ty adresy upravit. Ale pořád ještě můžete adresář přesunout zpátky tam kde byl, jestli je to pro vás moc otravné.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'URL přesunutého adresáře přesunuto v   %s příspěvcích.');
@define('PLUGIN_ACTIVE', 'Aktivní');
@define('PLUGIN_INACTIVE', 'Neaktivní');
@define('PREFERENCE_USE_JS', 'Povolit použití advanced JS?');
@define('PREFERENCE_USE_JS_DESC', 'Je-li toto povoleno, budou povoleny sekce s advanced JavaScript, aby se zlepšila použitelnost. Např v sekci pro konfiguraci pluginů můžete pro přeskládání pluginů použít drag and drop (táhnout myší).');

@define('PREFERENCE_USE_JS_WARNING', '(Tato stránka používá advanced JavaScripting. Jestliže máte problémy s fungováním, zakažte prosím používání  advanced JS ve svém osobním nastavení nebo zakažte javascript v prohlížeči.)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'Cesta ke komentářům');
@define('PERM_SET_CHILD', 'Nastavte shodná práva pro všechny podřízené adresáře');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Zakázané pluginy');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Zakázané události');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Povolit Plugin ACL pro uživatelské skupiny?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Jestliže je volba "Plugin ACL pro uživatelské skupiny" v konfiguraci povolena, můžete určit, které skupiny uživatelů mohou provádět určité pluginy/události.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
@define('SET_TO_MODERATED', 'Moderate');
@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
@define('CENTER', 'center');
